@@ -1,4 +1,5 @@
-from apistar.client.auth import TokenAuthentication, SessionAuthentication
+# -*- coding: utf-8 -*-
+from apistar.client.auth import SessionAuthentication, TokenAuthentication
 
 
 class TokenSessionAuthentication(TokenAuthentication):
@@ -6,7 +7,13 @@ class TokenSessionAuthentication(TokenAuthentication):
     A token authentication that takes care of CSRF tokens.
     """
 
-    def __init__(self, token, scheme='Token', csrf_cookie_name='arkindex.csrf', csrf_header_name='X-CSRFToken'):
+    def __init__(
+        self,
+        token,
+        scheme="Token",
+        csrf_cookie_name="arkindex.csrf",
+        csrf_header_name="X-CSRFToken",
+    ):
         """
         :param str token: The API token to use.
         :param str scheme: The HTTP authentication scheme to use for token authentication.
